@@ -1,7 +1,9 @@
-import unittest
-from unittest import skip
+#  Copyright 2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  SPDX-License-Identifier: Apache-2.0
 
-from servicecatalog_puppet import constants
+import unittest
+
+from servicecatalog_puppet import constants, task_reference_constants
 
 
 class ImportedPortfoliosTest(unittest.TestCase):
@@ -38,9 +40,11 @@ class ImportedPortfoliosTest(unittest.TestCase):
             "organization": "o-sw3edla4pd",
             "ou": "ou-do8d-me7f39on",
             "region": region,
-            "manifest_section_names": {"imported-portfolios": True},
-            "manifest_item_names": {item_name: True},
-            "manifest_account_ids": {account_id: True},
+            task_reference_constants.MANIFEST_SECTION_NAMES: {
+                "imported-portfolios": True
+            },
+            task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+            task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
             "section_name": section_name,
             "item_name": item_name,
             "dependencies_by_reference": ["create-policies"],
@@ -72,9 +76,11 @@ class ImportedPortfoliosTest(unittest.TestCase):
                 "account_id": puppet_account_id,
                 "dependencies_by_reference": [],
                 "execution": "hub",
-                "manifest_account_ids": {account_id: True},
-                "manifest_item_names": {item_name: True},
-                "manifest_section_names": {"imported-portfolios": True},
+                task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
+                task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+                task_reference_constants.MANIFEST_SECTION_NAMES: {
+                    "imported-portfolios": True
+                },
                 "portfolio": portfolio,
                 "puppet_account_id": puppet_account_id,
                 "region": region,
@@ -93,9 +99,11 @@ class ImportedPortfoliosTest(unittest.TestCase):
                     "create-policies",
                 ],
                 "execution": "hub",
-                "manifest_account_ids": {account_id: True},
-                "manifest_item_names": {item_name: True},
-                "manifest_section_names": {"imported-portfolios": True},
+                task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
+                task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+                task_reference_constants.MANIFEST_SECTION_NAMES: {
+                    "imported-portfolios": True
+                },
                 "portfolio": portfolio,
                 "portfolio_task_reference": f"portfolio-local-{puppet_account_id}-{region}-{portfolio}",
                 "puppet_account_id": puppet_account_id,
@@ -114,9 +122,11 @@ class ImportedPortfoliosTest(unittest.TestCase):
                 "dependencies_by_reference": [
                     f"portfolio-local-{puppet_account_id}-{region}-{portfolio}"
                 ],
-                "manifest_account_ids": {account_id: True},
-                "manifest_item_names": {item_name: True},
-                "manifest_section_names": {"imported-portfolios": True},
+                task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
+                task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+                task_reference_constants.MANIFEST_SECTION_NAMES: {
+                    "imported-portfolios": True
+                },
                 "portfolio_task_reference": f"portfolio-local-{puppet_account_id}-{region}-{portfolio}",
                 "region": region,
                 "section_name": "describe-portfolio-shares",
@@ -138,9 +148,11 @@ class ImportedPortfoliosTest(unittest.TestCase):
                 ],
                 "describe_portfolio_shares_task_ref": f"describe-portfolio-shares-ORGANIZATIONAL_UNIT-portfolio-local-{puppet_account_id}-{region}-{portfolio}",
                 "execution": "hub",
-                "manifest_account_ids": {account_id: True},
-                "manifest_item_names": {item_name: True},
-                "manifest_section_names": {"imported-portfolios": True},
+                task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
+                task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+                task_reference_constants.MANIFEST_SECTION_NAMES: {
+                    "imported-portfolios": True
+                },
                 "ou_to_share_with": "ou-do8d-me7f39on",
                 "portfolio": portfolio,
                 "portfolio_task_reference": f"portfolio-local-{puppet_account_id}-{region}-{portfolio}",
@@ -162,11 +174,14 @@ class ImportedPortfoliosTest(unittest.TestCase):
                 "dependencies_by_reference": [
                     f"portfolio-local-{puppet_account_id}-{region}-{portfolio}",
                     "create-policies",
+                    f"portfolio_share_and_accept-ou-do8d-me7f39on-{region}-{portfolio}",
                 ],
                 "execution": "hub",
-                "manifest_account_ids": {account_id: True},
-                "manifest_item_names": {item_name: True},
-                "manifest_section_names": {"imported-portfolios": True},
+                task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
+                task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+                task_reference_constants.MANIFEST_SECTION_NAMES: {
+                    "imported-portfolios": True
+                },
                 "portfolio": portfolio,
                 "portfolio_task_reference": f"portfolio-local-{puppet_account_id}-{region}-{portfolio}",
                 "puppet_account_id": puppet_account_id,
@@ -186,12 +201,15 @@ class ImportedPortfoliosTest(unittest.TestCase):
                 "dependencies_by_reference": [
                     f"portfolio-local-{puppet_account_id}-{region}-{portfolio}",
                     "create-policies",
+                    f"portfolio_share_and_accept-ou-do8d-me7f39on-{region}-{portfolio}",
                 ],
                 "execution": "hub",
                 "spoke_local_portfolio_name": item_name,
-                "manifest_account_ids": {account_id: True},
-                "manifest_item_names": {item_name: True},
-                "manifest_section_names": {"imported-portfolios": True},
+                task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
+                task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+                task_reference_constants.MANIFEST_SECTION_NAMES: {
+                    "imported-portfolios": True
+                },
                 "portfolio": portfolio,
                 "portfolio_task_reference": f"portfolio-local-{puppet_account_id}-{region}-{portfolio}",
                 "region": region,
@@ -232,9 +250,11 @@ class ImportedPortfoliosTest(unittest.TestCase):
             "organization": "o-sw3edla4pd",
             "ou": "ou-do8d-me7f39on",
             "region": region,
-            "manifest_section_names": {"imported-portfolios": True},
-            "manifest_item_names": {item_name: True},
-            "manifest_account_ids": {account_id: True},
+            task_reference_constants.MANIFEST_SECTION_NAMES: {
+                "imported-portfolios": True
+            },
+            task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+            task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
             "section_name": section_name,
             "item_name": item_name,
             "dependencies_by_reference": [
@@ -270,9 +290,11 @@ class ImportedPortfoliosTest(unittest.TestCase):
                 "dependencies_by_reference": ["create-policies",],
                 "execution": "hub",
                 "spoke_local_portfolio_name": item_name,
-                "manifest_account_ids": {account_id: True},
-                "manifest_item_names": {item_name: True},
-                "manifest_section_names": {"imported-portfolios": True},
+                task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
+                task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+                task_reference_constants.MANIFEST_SECTION_NAMES: {
+                    "imported-portfolios": True
+                },
                 "portfolio": portfolio,
                 "region": region,
                 "section_name": "portfolio-associations",
@@ -310,9 +332,11 @@ class ImportedPortfoliosTest(unittest.TestCase):
             "organization": "o-sw3edla4pd",
             "ou": "ou-do8d-me7f39on",
             "region": region,
-            "manifest_section_names": {"imported-portfolios": True},
-            "manifest_item_names": {item_name: True},
-            "manifest_account_ids": {account_id: True},
+            task_reference_constants.MANIFEST_SECTION_NAMES: {
+                "imported-portfolios": True
+            },
+            task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+            task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
             "section_name": section_name,
             "launch_constraints": "thisisignored",
             "resource_update_constraints": "thisisignored",
@@ -346,12 +370,17 @@ class ImportedPortfoliosTest(unittest.TestCase):
             {
                 "spoke_local_portfolio_name": item_name,
                 "account_id": account_id,
-                "dependencies_by_reference": ["create-policies"],
+                "dependencies_by_reference": [
+                    "create-policies",
+                    f"portfolio_share_and_accept-ou-do8d-me7f39on-{region}-{portfolio}",
+                ],
                 "execution": "hub",
                 "launch_constraints": "thisisignored",
-                "manifest_account_ids": {account_id: True},
-                "manifest_item_names": {item_name: True},
-                "manifest_section_names": {"imported-portfolios": True},
+                task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
+                task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+                task_reference_constants.MANIFEST_SECTION_NAMES: {
+                    "imported-portfolios": True
+                },
                 "portfolio": portfolio,
                 "region": region,
                 "section_name": constants.PORTFOLIO_CONSTRAINTS_LAUNCH,
@@ -365,12 +394,17 @@ class ImportedPortfoliosTest(unittest.TestCase):
         self.assertEqual(
             {
                 "account_id": account_id,
-                "dependencies_by_reference": ["create-policies",],
+                "dependencies_by_reference": [
+                    "create-policies",
+                    f"portfolio_share_and_accept-ou-do8d-me7f39on-{region}-{portfolio}",
+                ],
                 "resource_update_constraints": "thisisignored",
                 "execution": "hub",
-                "manifest_account_ids": {account_id: True},
-                "manifest_item_names": {item_name: True},
-                "manifest_section_names": {"imported-portfolios": True},
+                task_reference_constants.MANIFEST_ACCOUNT_IDS: {account_id: True},
+                task_reference_constants.MANIFEST_ITEM_NAMES: {item_name: True},
+                task_reference_constants.MANIFEST_SECTION_NAMES: {
+                    "imported-portfolios": True
+                },
                 "portfolio": portfolio,
                 "region": region,
                 "section_name": constants.PORTFOLIO_CONSTRAINTS_RESOURCE_UPDATE,
