@@ -1,4 +1,4 @@
-#  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  Copyright 2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #  SPDX-License-Identifier: Apache-2.0
 from servicecatalog_puppet import constants, serialisation_utils
 from servicecatalog_puppet.workflow import workflow_utils
@@ -6,7 +6,7 @@ from servicecatalog_puppet.workflow import workflow_utils
 
 def generate(puppet_account_id, all_tasks, output_file_path):
     tasks_to_include = dict()
-    generate_manifest_ref = "generate-manifest"
+    generate_manifest_ref = constants.GENERATE_MANIFEST
     for task_name, task in all_tasks.get("all_tasks").items():
         execution = task.get("execution", constants.EXECUTION_MODE_DEFAULT)
         if execution in [constants.EXECUTION_MODE_HUB, constants.EXECUTION_MODE_ASYNC]:
@@ -31,7 +31,7 @@ def generate(puppet_account_id, all_tasks, output_file_path):
                     constants.PORTFOLIO_SHARE_AND_ACCEPT_AWS_ORGANIZATIONS,
                 ]
         else:
-            raise Exception("Unhandled execution")
+            raise Exception(f"Unhandled execution: {execution}")
 
         if should_include:
             tasks_to_include[task_name] = task
