@@ -1,4 +1,4 @@
-#  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  Copyright 2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #  SPDX-License-Identifier: Apache-2.0
 
 import json
@@ -60,7 +60,7 @@ def run_tasks(
     execution_mode="hub",
     on_complete_url=None,
     running_exploded=False,
-    tasks_to_run_filtered=[],
+    tasks_to_run_filtered=None,
     manifest_files_path="",
     manifest_task_reference_file_path="",
 ):
